@@ -81,3 +81,17 @@ impl Deref for Page {
 	}
 
 }
+
+impl Index<Span> for Page {
+
+	type Output = str;
+
+	fn index(&self, span: Span) -> &Self::Output {
+	
+		let range = span.start.index .. span.end.index();
+
+		&self.string[range]
+
+	}
+
+}
\ No newline at end of file
